@@ -1,5 +1,3 @@
-
-
 def parse_pycoco_metrics(epoch: int, pycoco_train_metrics: str, pycoco_eval_metrics: str) -> dict:
     """Parses text output of the pycocotools metrics for the train loop and the eval loop for one epoch."""
     import re
@@ -13,9 +11,15 @@ def parse_pycoco_metrics(epoch: int, pycoco_train_metrics: str, pycoco_eval_metr
         r = re.search('[^(]+\(([^)]+)\) @\[ IoU=([^|]+)\| area=([^|]+)\| maxDets=([^\]]+)] = (-?\d+.\d+)', line)
         if not r:
             continue
-        iou, area, value = r.group(2).strip().replace("0.", "."), r.group(3).strip(), r.group(5)
-        iou = "" if ":" in iou else iou + "IOU"
-        area = "" if area == "all" else " (" + area + ")"
-        name = "m" + r.group(1) + "@" + iou + r.group(4).strip() + area
+        m, iou, area, maxDets, value = r.group(1).strip(), r.group(2).strip().replace("0.", "."), r.group(3).strip(), r.group(4).strip(), r.group(5)
+        metric = m
+        if m == "AP":
+            metric = "Average Precision"
+        if m == "AR":
+            metric = "Average Recall"
+        iou = " @" + iou + "IoU "
+        area = "" if area == "all" else "(" + area + ")"
+        maxDets = "" if maxDets == "100" else "[" + maxDets + "]" 
+        name = metric + iou + area + maxDets
         record[name] = float(value)
     return record
\ No newline at end of file
